from django.db import models


class Contact(models.Model):

    type = models.CharField(max_length=100)
    name = models.CharField(max_length=255)
    email = models.EmailField(max_length=100)
    sponsor = models.ForeignKey("Sponsor")

    def __unicode__(self):
        return '%s - %s' % (self.name, self.email)


class Category(models.Model):

    name = models.CharField(max_length=120)

    def __unicode__(self):
        return self.name


class Sponsor(models.Model):

    name = models.CharField(max_length=100)
    description = models.CharField(max_length=255)
    url = models.URLField()
    category = models.ForeignKey(Category)
    logo = models.ImageField(upload_to='sponsors')

    def __unicode__(self):
        return self.name



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'Contact'
        db.create_table('sponsors_contact', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('type', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('email', self.gf('django.db.models.fields.EmailField')(max_length=100)),
            ('sponsor', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['sponsors.Sponsor'])),
        ))
        db.send_create_signal('sponsors', ['Contact'])

        # Adding model 'Category'
        db.create_table('sponsors_category', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=120)),
        ))
        db.send_create_signal('sponsors', ['Category'])

        # Adding model 'Sponsor'
        db.create_table('sponsors_sponsor', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('description', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('url', self.gf('django.db.models.fields.URLField')(max_length=200)),
            ('category', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['sponsors.Category'])),
            ('logo', self.gf('django.db.models.fields.files.ImageField')(max_length=100)),
        ))
        db.send_create_signal('sponsors', ['Sponsor'])


    def backwards(self, orm):
        
        # Deleting model 'Contact'
        db.delete_table('sponsors_contact')

        # Deleting model 'Category'
        db.delete_table('sponsors_category')

        # Deleting model 'Sponsor'
        db.delete_table('sponsors_sponsor')


    models = {
        'sponsors.category': {
            'Meta': {'object_name': 'Category'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '120'})
        },
        'sponsors.contact': {
            'Meta': {'object_name': 'Contact'},
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'sponsor': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['sponsors.Sponsor']"}),
            'type': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'sponsors.sponsor': {
            'Meta': {'object_name': 'Sponsor'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['sponsors.Category']"}),
            'description': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'logo': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'url': ('django.db.models.fields.URLField', [], {'max_length': '200'})
        }
    }

    complete_apps = ['sponsors']



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'Event'
        db.create_table('events_event', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('description', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('date', self.gf('django.db.models.fields.DateField')()),
            ('location', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('address', self.gf('django.db.models.fields.CharField')(max_length=250)),
        ))
        db.send_create_signal('events', ['Event'])


    def backwards(self, orm):
        
        # Deleting model 'Event'
        db.delete_table('events_event')


    models = {
        'events.event': {
            'Meta': {'object_name': 'Event'},
            'address': ('django.db.models.fields.CharField', [], {'max_length': '250'}),
            'date': ('django.db.models.fields.DateField', [], {}),
            'description': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'location': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        }
    }

    complete_apps = ['events']



from django.views.generic import TemplateView

from events.models import Event


class IndexView(TemplateView):

    template_name = 'index.html'


class AboutView(TemplateView):

    template_name = 'about.html'

    def get_object(self):
        return Event.objects.get(pk=1)

    def get_context_data(self):
        return {
            'event': self.get_object()
        }

    def get(self, request, *args, **kwargs):
        return self.render_to_response(context=self.get_context_data)



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'Location'
        db.create_table('events_location', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=150)),
            ('event', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['events.Event'])),
            ('address', self.gf('django.db.models.fields.CharField')(max_length=255)),
        ))
        db.send_create_signal('events', ['Location'])

        # Deleting field 'Event.address'
        db.delete_column('events_event', 'address')

        # Deleting field 'Event.location'
        db.delete_column('events_event', 'location')


    def backwards(self, orm):
        
        # Deleting model 'Location'
        db.delete_table('events_location')

        # Adding field 'Event.address'
        db.add_column('events_event', 'address', self.gf('django.db.models.fields.CharField')(default=None, max_length=250), keep_default=False)

        # Adding field 'Event.location'
        db.add_column('events_event', 'location', self.gf('django.db.models.fields.CharField')(default=None, max_length=100), keep_default=False)


    models = {
        'events.event': {
            'Meta': {'object_name': 'Event'},
            'date': ('django.db.models.fields.DateField', [], {}),
            'description': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '50', 'db_index': 'True'}),
            'url': ('django.db.models.fields.CharField', [], {'max_length': '250', 'blank': 'True'})
        },
        'events.location': {
            'Meta': {'object_name': 'Location'},
            'address': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['events.Event']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '150'})
        }
    }

    complete_apps = ['events']



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'Subscriber'
        db.create_table('registration_subscriber', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('email', self.gf('django.db.models.fields.EmailField')(max_length=255)),
            ('subscription_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
        ))
        db.send_create_signal('registration', ['Subscriber'])


    def backwards(self, orm):
        
        # Deleting model 'Subscriber'
        db.delete_table('registration_subscriber')


    models = {
        'registration.subscriber': {
            'Meta': {'object_name': 'Subscriber'},
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '255'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'subscription_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['registration']



# -*- coding: utf-8 -*-
from django.conf.urls.defaults import patterns
from django.contrib import admin
from django.template import response

from registration import forms, helpers, models


class SubscriberAdmin(admin.ModelAdmin):

    def __init__(self, *args, **kwargs):
        super(SubscriberAdmin, self).__init__(*args, **kwargs)
        self.mail_sender = helpers.MailSender()

    def get_urls(self):
        urls = super(SubscriberAdmin, self).get_urls()
        custom_urls = patterns('',
            (r'^send-mail/$', self.admin_site.admin_view(self.show_mail_form))
        )
        return custom_urls + urls

    def show_mail_form(self, request):
        if request.method == "POST":
            return self.send_mail(request)

        context = {"form": forms.SendMailForm()}
        return response.TemplateResponse(request, "send_subscribers_mail.html", context)

    def send_mail(self, request):
        form = forms.SendMailForm(request.POST)

        if form.is_valid():
            subscribers = models.Subscriber.objects.all()
            recipients = [s.email for s in subscribers]
            self.mail_sender.send_mail(form.data["subject"], form.data["body"], recipients)
            context = {"subscribers": subscribers}
            return response.TemplateResponse(request, "subscribers_mail_sent.html", context)

        context = {"form": form}
        return response.TemplateResponse(request, "send_subscribers_mail.html", context)

admin.site.register(models.Subscriber, SubscriberAdmin)



# -*- coding: utf-8 -*-
from django import forms

from registration import models


class SendMailForm(forms.Form):
    subject = forms.CharField(max_length=300)
    body = forms.CharField(max_length=5000, widget=forms.Textarea())


class SubscriberForm(forms.ModelForm):
    class Meta:
        model = models.Subscriber
        exclude = ('subscription_date',)



from django.views.generic.base import TemplateResponseMixin
from django.views.generic.edit import ModelFormMixin, ProcessFormView

from events.forms import BootstrapForm
from events.models import Event


class BaseCreateUpdateView(ModelFormMixin, ProcessFormView):

    def get(self, request, *args, **kwargs):
        self.set_object()
        return super(BaseCreateUpdateView, self).get(request, *args, **kwargs)

    def post(self, request, *args, **kwargs):
        self.set_object()
        return super(BaseCreateUpdateView, self).post(request, *args, **kwargs)

    def set_object(self):
        events = self.model.objects.all()

        if events.count():
            self.object = events[0]
        else:
            self.object = None


class BootstrapView(TemplateResponseMixin, BaseCreateUpdateView):

    model = Event
    form_class = BootstrapForm
    template_name = 'event_form.html'
    success_url = '/bootstrap'



from django.db.models.signals import pre_save
from django.db import models
from django.template.defaultfilters import slugify

from transmeta import TransMeta

class Location(models.Model):

    title = models.CharField(max_length=150)
    event = models.ForeignKey("Event")
    address = models.CharField(max_length=255)


class Event(models.Model):
    __metaclass__ = TransMeta

    name = models.CharField(max_length=100)
    description = models.CharField(max_length=200)
    date = models.DateField()
    slug = models.SlugField()
    logo = models.ImageField(upload_to='event_logo')

    class Meta:
        translate = ('description',)

    def __unicode__(self):
        return self.name

    def get_absolute_url(self):
        return 'event/%s' % self.slug


def generate_slug(instance, *args, **kwargs):
    instance.slug = slugify(instance.name)


pre_save.connect(generate_slug, sender=Event)



# -*- coding: utf-8 -*-

from django.core import mail


class MailSender(object):

    def build_message(self, subject, body, recipients):
        return mail.EmailMessage(subject, body, bcc=recipients)

    def send_mail(self, subject, body, recipients):
        message = self.build_message(subject, body, recipients)
        message.send(fail_silently=True)
        return message
